"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _trimNewlines = require("trim-newlines");
var _style = require("./../../utils/style");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const SyntaxHighlighter = ({
  code,
  language,
  languageMap,
  theme,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [highlightedNodes, setHighlightedNodes] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    const highlightCode = async () => {
      if (!languageMap[language]) {
        console.warn(`Warning: Language "${language}" not found in the language map. Falling back to "plaintext".`);
      }
      const highlighter = await (0, _core.createHighlighterCore)({
        engine: (0, _engineJavascript.createJavaScriptRegexEngine)(),
        langs: Object.values(languageMap)
      });
      console.log('Highlighter:', highlighter);
      const tokens = highlighter.codeToHast(code, {
        lang: language,
        theme
      });
      console.log('Tokens:', tokens || null);
      setHighlightedNodes(tokens.children || null);
    };
    highlightCode();
  }, [code, language, languageMap, theme]);
  const stylesheet = (0, _react.useMemo)(() => (0, _style.getRNStylesFromShikiStyle)(theme), [theme]);
  const getStylesForNode = node => {
    const classes = node.properties?.className ?? [];
    return classes.map(c => stylesheet[c]).filter(Boolean);
  };
  const renderNode = (nodes, keyPrefix = 'row') => nodes.reduce((acc, node, index) => {
    const keyPrefixWithIndex = `${keyPrefix}_${index}`;
    if (node.children) {
      const styles = _reactNative.StyleSheet.flatten([textStyle, {
        color: stylesheet.shiki?.color
      }, ...getStylesForNode(node)]);
      console.log('Styles:', styles);
      acc.push(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: styles,
        children: renderNode(node.children, `${keyPrefixWithIndex}_child`)
      }, keyPrefixWithIndex));
    }
    if (node.value) {
      acc.push((0, _trimNewlines.trimNewlines)(String(node.value)));
    }
    return acc;
  }, []);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    contentContainerStyle: [stylesheet.shiki, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: highlightedNodes && renderNode(highlightedNodes)
    })
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map