"use strict";

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import React, { useEffect, useMemo, useState } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import { trimNewlines } from 'trim-newlines';
import { getRNStylesFromShikiStyle } from './../../utils/style';
import { jsx as _jsx } from "react/jsx-runtime";
const SyntaxHighlighter = ({
  code,
  language,
  languageMap,
  theme,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [highlightedNodes, setHighlightedNodes] = useState(null);
  useEffect(() => {
    const highlightCode = async () => {
      if (!languageMap[language]) {
        console.warn(`Warning: Language "${language}" not found in the language map. Falling back to "plaintext".`);
      }
      const highlighter = await createHighlighterCore({
        engine: createJavaScriptRegexEngine(),
        langs: Object.values(languageMap)
      });
      console.log('Highlighter:', highlighter);
      const tokens = highlighter.codeToHast(code, {
        lang: language,
        theme
      });
      console.log('Tokens:', tokens || null);
      setHighlightedNodes(tokens.children || null);
    };
    highlightCode();
  }, [code, language, languageMap, theme]);
  const stylesheet = useMemo(() => getRNStylesFromShikiStyle(theme), [theme]);
  const getStylesForNode = node => {
    const classes = node.properties?.className ?? [];
    return classes.map(c => stylesheet[c]).filter(Boolean);
  };
  const renderNode = (nodes, keyPrefix = 'row') => nodes.reduce((acc, node, index) => {
    const keyPrefixWithIndex = `${keyPrefix}_${index}`;
    if (node.children) {
      const styles = StyleSheet.flatten([textStyle, {
        color: stylesheet.shiki?.color
      }, ...getStylesForNode(node)]);
      console.log('Styles:', styles);
      acc.push(/*#__PURE__*/_jsx(Text, {
        style: styles,
        children: renderNode(node.children, `${keyPrefixWithIndex}_child`)
      }, keyPrefixWithIndex));
    }
    if (node.value) {
      acc.push(trimNewlines(String(node.value)));
    }
    return acc;
  }, []);
  return /*#__PURE__*/_jsx(ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    contentContainerStyle: [stylesheet.shiki, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: highlightedNodes && renderNode(highlightedNodes)
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map